==> forestry_1.12.2-5.8.2.401-sources.jar: forestry/arboriculture/items/ItemBlockWoodDoor.java <==
package forestry.arboriculture.items;

import net.minecraft.block.Block;
import net.minecraft.block.SoundType;
import net.minecraft.block.state.IBlockState;
import net.minecraft.entity.player.EntityPlayer;
import net.minecraft.item.ItemDoor;
import net.minecraft.item.ItemStack;
import net.minecraft.util.EnumActionResult;
import net.minecraft.util.EnumFacing;
import net.minecraft.util.EnumHand;
import net.minecraft.util.SoundCategory;
import net.minecraft.util.math.BlockPos;
import net.minecraft.world.World;

import forestry.arboriculture.blocks.BlockArbDoor;

public class ItemBlockWoodDoor extends ItemBlockWood<BlockArbDoor> {

	public ItemBlockWoodDoor(BlockArbDoor block) {
		super(block);
	}

	/**
	 * Copy of {@link ItemDoor#onItemUse}
	 */
	@Override
	public EnumActionResult func_180614_a(EntityPlayer player, World worldIn, BlockPos pos, EnumHand hand, EnumFacing facing, float hitX, float hitY, float hitZ) {
		if (facing != EnumFacing.UP) {
			return EnumActionResult.FAIL;
		} else {
			IBlockState iblockstate = worldIn.func_180495_p(pos);
			Block block = iblockstate.func_177230_c();

			if (!block.func_176200_f(worldIn, pos)) {
				pos = pos.func_177972_a(facing);
			}

			ItemStack itemstack = player.func_184586_b(hand);

			if (player.func_175151_a(pos, facing, itemstack) && this.field_150939_a.func_176196_c(worldIn, pos)) {
				EnumFacing enumfacing = EnumFacing.func_176733_a(player.field_70177_z);
				int i = enumfacing.func_82601_c();
				int j = enumfacing.func_82599_e();
				boolean flag = i < 0 && hitZ < 0.5F || i > 0 && hitZ > 0.5F || j < 0 && hitX > 0.5F || j > 0 && hitX < 0.5F;
				ItemDoor.func_179235_a(worldIn, pos, enumfacing, this.field_150939_a, flag);
				SoundType soundtype = worldIn.func_180495_p(pos).func_177230_c().getSoundType(worldIn.func_180495_p(pos), worldIn, pos, player);
				worldIn.func_184133_a(player, pos, soundtype.func_185841_e(), SoundCategory.BLOCKS, (soundtype.func_185843_a() + 1.0F) / 2.0F, soundtype.func_185847_b() * 0.8F);
				itemstack.func_190918_g(1);
				return EnumActionResult.SUCCESS;
			} else {
				return EnumActionResult.FAIL;
			}
		}
	}

	@Override
	public int getItemBurnTime(ItemStack itemStack) {
		if (func_179223_d().isFireproof()) {
			return 0;
		} else {
			return 200;
		}
	}
}

==> forestry_1.12-5.4.2.126-sources.jar: forestry/arboriculture/items/ItemBlockWoodDoor.java <==
package forestry.arboriculture.items;

import forestry.arboriculture.blocks.BlockArbDoor;
import net.minecraft.block.Block;
import net.minecraft.block.SoundType;
import net.minecraft.block.state.IBlockState;
import net.minecraft.entity.player.EntityPlayer;
import net.minecraft.item.ItemDoor;
import net.minecraft.item.ItemStack;
import net.minecraft.util.EnumActionResult;
import net.minecraft.util.EnumFacing;
import net.minecraft.util.EnumHand;
import net.minecraft.util.SoundCategory;
import net.minecraft.util.math.BlockPos;
import net.minecraft.world.World;

public class ItemBlockWoodDoor extends ItemBlockWood<BlockArbDoor> {

	public ItemBlockWoodDoor(Block block) {
		super(block);
	}

	/**
	 * Copy of {@link ItemDoor#onItemUse}
	 */
	@Override
	public EnumActionResult func_180614_a(EntityPlayer player, World worldIn, BlockPos pos, EnumHand hand, EnumFacing facing, float hitX, float hitY, float hitZ) {
		if (facing != EnumFacing.UP) {
			return EnumActionResult.FAIL;
		} else {
			IBlockState iblockstate = worldIn.func_180495_p(pos);
			Block block = iblockstate.func_177230_c();

			if (!block.func_176200_f(worldIn, pos)) {
				pos = pos.func_177972_a(facing);
			}

			ItemStack itemstack = player.func_184586_b(hand);

			if (player.func_175151_a(pos, facing, itemstack) && this.field_150939_a.func_176196_c(worldIn, pos)) {
				EnumFacing enumfacing = EnumFacing.func_176733_a(player.field_70177_z);
				int i = enumfacing.func_82601_c();
				int j = enumfacing.func_82599_e();
				boolean flag = i < 0 && hitZ < 0.5F || i > 0 && hitZ > 0.5F || j < 0 && hitX > 0.5F || j > 0 && hitX < 0.5F;
				ItemDoor.func_179235_a(worldIn, pos, enumfacing, this.field_150939_a, flag);
				SoundType soundtype = worldIn.func_180495_p(pos).func_177230_c().getSoundType(worldIn.func_180495_p(pos), worldIn, pos, player);
				worldIn.func_184133_a(player, pos, soundtype.func_185841_e(), SoundCategory.BLOCKS, (soundtype.func_185843_a() + 1.0F) / 2.0F, soundtype.func_185847_b() * 0.8F);
				itemstack.func_190918_g(1);
				return EnumActionResult.SUCCESS;
			} else {
				return EnumActionResult.FAIL;
			}
		}
	}
	
	@Override
	public int getItemBurnTime(ItemStack itemStack) {
		if (func_179223_d().isFireproof()) {
			return 0;
		} else {
			return 200;
		}
	}
}
